@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012 - 2021 Pytroll developers
+# Copyright (c) 2012 - 2023 Pytroll developers
 #
 # Author(s):
 #
@@ -44,6 +44,9 @@ from datetime import datetime, timedelta
 from time import sleep
 from urllib.parse import SplitResult, urlsplit, urlunsplit
 
+from trollsift import compose
+
+from pytroll_collectors.config import read_config
 from posttroll.message import Message
 from posttroll.publisher import Publish
 from pytroll_collectors.helper_functions import is_uri_on_server
@@ -58,12 +61,19 @@ JPSS_INSTRUMENTS_FROM_FILENAMES = {"RATMS-RNSCA_": "atms",
 JPSS_PLATFORM_NAME = {'npp': 'Suomi-NPP',
                       'jpss1': 'NOAA-20',
                       'noaa20': 'NOAA-20',
+                      'noaa21': 'NOAA-21',
+                      'noaa21': 'NOAA-22',
+                      'noaa21': 'NOAA-23',
                       'j01': 'NOAA-20',
-                      'j02': 'NOAA-21'}
+                      'j02': 'NOAA-21',
+                      'j03': 'NOAA-22',
+                      'j04': 'NOAA-23'}
 
 SCISYS_NAMES = {'Suomi-NPP': 'NPP',
                 'NOAA-20': 'NOAA 20',
-                'NOAA-21': 'NOAA 21'}
+                'NOAA-21': 'NOAA 21',
+                'NOAA-22': 'NOAA 22',
+                'NOAA-23': 'NOAA 23'}
 
 
 class TwoMetMessage(object):
@@ -140,9 +150,9 @@ class PassRecorder(dict):
         """Get a pass."""
         utctime, satellite = key
         for (rectime, recsat), val in self.iter():
-            if(recsat == satellite and
-               (abs(rectime - utctime)).seconds < 30 * 60 and
-               (abs(rectime - utctime)).days == 0):
+            if (recsat == satellite and
+                (abs(rectime - utctime)).seconds < 30 * 60 and
+                    (abs(rectime - utctime)).days == 0):
                 return val
         return default
 
@@ -493,19 +503,23 @@ class GMCSubscriber(object):
         self.loop = False
 
 
-def receive_from_zmq(host, port, station, environment, excluded_platforms,
-                     target_server, ftp_prefix, topic_postfix,
+def get_subject_from_message_and_config(to_send, config):
+    """Get the publish topic from the message and the yaml configuration settings."""
+    return compose(config['publish_topic_pattern'], to_send)
+
+
+def receive_from_zmq(config_filename,
+                     target_server, ftp_prefix,
                      publish_port=0, nameservers=None, days=1):
     """Receive 2met! messages from zeromq."""
     logger.debug("target_server: %s", str(target_server))
     logger.debug("ftp_prefix: %s", str(ftp_prefix))
-    logger.debug("topic_postfix: %s", str(topic_postfix))
-    logger.debug("station %s", str(station))
     logger.debug(type(target_server))
 
-    # socket = Subscriber(["tcp://localhost:9331"], ["2met!"])
-    sock = GMCSubscriber(host, port)
-    msg_rec = MessageReceiver(host, excluded_platforms,
+    config = read_config(config_filename)
+
+    sock = GMCSubscriber(config['host'], config['port'])
+    msg_rec = MessageReceiver(config['host'], config['excluded_platforms'],
                               target_server, ftp_prefix)
 
     with Publish("receiver", port=publish_port,
@@ -520,19 +534,10 @@ def receive_from_zmq(host, port, station, environment, excluded_platforms,
             logger.debug("to_send: %s", str(to_send))
             if to_send is None:
                 continue
-            if topic_postfix is not None:
-                subject = "/".join(("", to_send['format'],
-                                   to_send['data_processing_level'],
-                                   topic_postfix))
-            else:
-                subject = "/".join(("", to_send['format'],
-                                   to_send['data_processing_level'],
-                                   station, environment,
-                                   "polar", "direct_readout"))
+
+            subject = get_subject_from_message_and_config(to_send, config)
             logger.debug("Subject: %s", str(subject))
-            msg = Message(subject,
-                          "file",
-                          to_send).encode()
+            msg = Message(subject, "file", to_send).encode()
             logger.debug("publishing %s", str(msg))
             pub.send(msg)
             if days:
