@@ -37,17 +37,17 @@ reception system produces multiple files for the same overpass.
 
 import datetime as dt
 import logging.handlers
+import os
+import signal
 from abc import ABCMeta, abstractmethod
 from collections import OrderedDict
 from enum import Enum
-import glob
-import os
 
 import trollsift
 from posttroll import message as pmessage
 from posttroll.listener import ListenerContainer
 from queue import Empty
-from urllib.parse import urlparse
+from urllib.parse import urlparse, urlunparse
 
 from pytroll_collectors.utils import check_nameserver_options
 from pytroll_collectors.utils import create_started_publisher_from_config
@@ -159,15 +159,17 @@ class MessageParser(Parser):
 class Message:
     """A message object."""
 
-    def __init__(self, posttroll_message, pattern):
+    def __init__(self, posttroll_message, pattern, drop_scheme=False):
         """Set up the message."""
         self.pattern = pattern
-        self.message_data = posttroll_message.data.copy()
+        self._drop_scheme = drop_scheme
+        posttroll_message = self._handle_scheme(posttroll_message)
+        self.message_data = posttroll_message.data
         self.type = posttroll_message.type
         self._posttroll_message = posttroll_message
         self.metadata = pattern.parser.parse(self.message_data)
         self._time_name = self.pattern.time_name
-        self._adjust_time_by_flooring()
+        self.adjust_time_by_flooring()
 
     @property
     def id_time(self):
@@ -178,27 +180,46 @@ class Message:
         """Get a unique id for the message."""
         return self.pattern.parser.uid(self.message_data)
 
-    def _adjust_time_by_flooring(self):
+    def adjust_time_by_flooring(self):
         """Floor time to full minutes."""
-        group_by_minutes = self.pattern.group_by_minutes
+        self._adjust_time_by_flooring(self.metadata, self.pattern.group_by_minutes, self.pattern.time_name)
+
+    def _adjust_time_by_flooring(self, metadata, group_by_minutes, time_name):
         if group_by_minutes is None:
-            return self.metadata
-
-        start_time = self.metadata[self.pattern.time_name]
-        minutes = start_time.minute
+            return
+        time_item = metadata[time_name]
+        minutes = time_item.minute
         floor_minutes = int(minutes / group_by_minutes) * group_by_minutes
-        start_time = dt.datetime(start_time.year, start_time.month,
-                                 start_time.day, start_time.hour, floor_minutes, 0)
-        self.metadata[self.pattern.time_name] = start_time
+        time_item = dt.datetime(time_item.year, time_item.month,
+                                time_item.day, time_item.hour, floor_minutes, 0)
+        metadata[time_name] = time_item
 
-        return self.metadata
+    def _handle_scheme(self, posttroll_message):
+        message_data = posttroll_message.data.copy()
+        if self._drop_scheme:
+            url_parts = urlparse(message_data['uri'])
+            uri = urlunparse(
+                (
+                    '',
+                    '',
+                    url_parts.path,
+                    '',
+                    '',
+                    ''
+                )
+            )
+            message_data['uri'] = uri
+            posttroll_message.data = message_data
+        return posttroll_message
 
     @property
     def filtered_metadata(self):
         """Merge the metadata."""
-        return filter_metadata(self.metadata, self.message_data,
+        meta = filter_metadata(self.metadata, self.message_data,
                                keep_parsed_keys=self.pattern._global_keep_parsed_keys,
                                local_keep_parsed_keys=self.pattern._local_keep_parsed_keys)
+        self._adjust_time_by_flooring(meta, self.pattern.group_by_minutes, self.pattern.time_name)
+        return meta
 
 
 class Slot:
@@ -206,7 +227,7 @@ class Slot:
 
     def __init__(self, timestamp, metadata, patterns, timeliness, num_files_premature_publish):
         """Set up the slot."""
-        self.timestamp = timestamp
+        self.timestamp = str(timestamp)
         self._info = dict()
         self._timeliness = timeliness
         self._num_files_premature_publish = num_files_premature_publish
@@ -302,14 +323,9 @@ class Slot:
                         'segment' not in parser.fmt):
                     result.add(parser.globify(meta))
                 continue
-            segments = segments.split('-')
-            if len(segments) > 1:
-                format_string = '%d'
-                if len(segments[0]) > 1 and segments[0][0] == '0':
-                    format_string = '%0' + str(len(segments[0])) + 'd'
-                segments = [format_string % i
-                            for i in range(int(segments[0]),
-                                           int(segments[-1]) + 1)]
+
+            segments = _create_segment_list(segments)
+
             meta['channel_name'] = channel_name
             for seg in segments:
                 meta['segment'] = seg
@@ -478,6 +494,24 @@ class Slot:
             return Status.SLOT_READY_BUT_WAIT_FOR_MORE
 
 
+def _create_segment_list(segments):
+    segments = segments.split('-')
+    if len(segments) == 2:
+        try:
+            range_start = int(segments[0])
+            range_end = int(segments[-1]) + 1
+        except ValueError:
+            segments = ['-'.join(segments)]
+        else:
+            format_string = '%d'
+            if len(segments[0]) > 1 and segments[0][0] == '0':
+                format_string = '%0' + str(len(segments[0])) + 'd'
+            segments = [format_string % i
+                        for i in range(range_start,
+                                       range_end)]
+    return segments
+
+
 class Pattern:
     """A pattern to watch for."""
 
@@ -577,6 +611,7 @@ class SegmentGatherer(object):
         self._group_by_minutes = self._config.get('group_by_minutes', None)
 
         self._loop = False
+        self._sigterm_caught = False
         self._providing_server = self._config.get('providing_server')
         self._is_first_message_after_start = True
 
@@ -678,9 +713,10 @@ class SegmentGatherer(object):
     def run(self):
         """Run SegmentGatherer."""
         self._setup_messaging()
+        signal.signal(signal.SIGTERM, self._handle_sigterm)
 
         self._loop = True
-        while self._loop:
+        while self._keep_running():
             self.triage_slots()
 
             # Check listener for new messages
@@ -689,8 +725,7 @@ class SegmentGatherer(object):
             except AttributeError:
                 msg = self._listener.queue.get(True, 1)
             except KeyboardInterrupt:
-                self.stop()
-                continue
+                break
             except Empty:
                 continue
 
@@ -700,6 +735,16 @@ class SegmentGatherer(object):
                     continue
                 logger.info("New message received: %s", str(msg))
                 self.process(msg)
+        self.stop()
+
+    def _handle_sigterm(self, signum, frame):
+        logging.info("Caught SIGTERM, shutting down when all collections are finished.")
+        self._sigterm_caught = True
+
+    def _keep_running(self):
+        if not self._loop or (self._sigterm_caught and not self.slots):
+            return False
+        return True
 
     def triage_slots(self):
         """Check if there are slots ready for publication."""
@@ -769,7 +814,8 @@ class SegmentGatherer(object):
         for pattern in self._patterns.values():
             try:
                 if pattern.parser.matches(msg):
-                    return Message(msg, pattern)
+                    drop_scheme = self._config.get('all_files_are_local', False)
+                    return Message(msg, pattern, drop_scheme=drop_scheme)
             except KeyError as err:
                 logger.debug("No key %s in message.", str(err))
         raise TypeError
@@ -791,12 +837,12 @@ class SegmentGatherer(object):
 
     def _create_slot(self, message):
         """Init wanted, all and critical files."""
-        timestamp = str(message.id_time)
-        logger.debug("Adding new slot: %s", timestamp)
+        timestamp = message.id_time
+        logger.debug(f"Adding new slot: {timestamp}")
 
         slot = Slot(timestamp, message.filtered_metadata, self._patterns, self._timeliness,
                     self._num_files_premature_publish)
-        self.slots[timestamp] = slot
+        self.slots[str(timestamp)] = slot
         return slot
 
     def check_if_time_is_in_interval(self, time_range, raw_start_time):
@@ -851,10 +897,32 @@ class SegmentGatherer(object):
 
 def _get_existing_files_from_message(message):
     mask = message.pattern.parser.globify({})
-    path = urlparse(message.message_data["uri"]).path
-    base_dir = os.path.dirname(path)
+    url_parts = urlparse(message.message_data["uri"])
 
-    return glob.glob(os.path.join(base_dir, mask))
+    return _fsspec_glob(url_parts, mask)
+
+
+def _fsspec_glob(url_parts, mask):
+    import fsspec
+
+    pattern = urlunparse(
+        (
+            url_parts.scheme,
+            url_parts.netloc,
+            '/'.join(url_parts.path.split('/')[:-1]) + '/' + mask,
+            '',
+            '',
+            ''
+        )
+    )
+
+    fs_ = fsspec.filesystem(url_parts.scheme)
+    files = fs_.glob(pattern)
+    # There might be no scheme in the returned filenames, so add it if scheme is defined
+    if url_parts.scheme:
+        files = [url_parts.scheme + '://' + f for f in files if not f.startswith(
+            url_parts.scheme + '://')]
+    return files
 
 
 def _copy_without_ignore_items(the_dict, ignored_keys='ignore'):
@@ -963,6 +1031,11 @@ def ini_to_dict(fname, section):
     except (NoOptionError, ValueError):
         conf['check_existing_files_after_start'] = False
 
+    try:
+        conf['all_files_are_local'] = config.getboolean(section, "all_files_are_local")
+    except (NoOptionError, ValueError):
+        conf['all_files_are_local'] = False
+
     return conf
 
 
