@@ -13,7 +13,7 @@ from pytroll_collectors.tests.test_s3stalker import ls_output, fs_json, subject,
 class TestMessageComposer:
     """Test case for the message composer."""
 
-    def setup(self):
+    def setup_method(self):
         """Set up message composer tests."""
         self.ls_output = deepcopy(ls_output)
 
@@ -121,8 +121,8 @@ class TestUnpackMessage:
     @pytest.mark.parametrize(
         ("packing", "create_packfile", "filesystem_class"),
         [
-            ("tar", create_tar_file, "fsspec.implementations.tar.TarFileSystem"),
-            ("zip", create_zip_file, "fsspec.implementations.zip.ZipFileSystem"),
+            ("tar", create_tar_file, "fsspec.implementations.tar:TarFileSystem"),
+            ("zip", create_zip_file, "fsspec.implementations.zip:ZipFileSystem"),
         ]
     )
     def test_pack_file_extract(self, packing, create_packfile, filesystem_class, tmp_path):
@@ -153,8 +153,8 @@ class TestUnpackMessage:
     @pytest.mark.parametrize(
         ("packing", "create_packfile", "filesystem_class"),
         [
-            ("tar", create_tar_file, "fsspec.implementations.tar.TarFileSystem"),
-            ("zip", create_zip_file, "fsspec.implementations.zip.ZipFileSystem"),
+            ("tar", create_tar_file, "fsspec.implementations.tar:TarFileSystem"),
+            ("zip", create_zip_file, "fsspec.implementations.zip:ZipFileSystem"),
         ]
     )
     def test_pack_local_file_extract(self, packing, create_packfile, filesystem_class, tmp_path):
@@ -184,8 +184,8 @@ class TestUnpackMessage:
     @pytest.mark.parametrize(
         ("packing", "create_packfile", "filesystem_class"),
         [
-            ("tar", create_tar_file, "fsspec.implementations.tar.TarFileSystem"),
-            ("zip", create_zip_file, "fsspec.implementations.zip.ZipFileSystem"),
+            ("tar", create_tar_file, "fsspec.implementations.tar:TarFileSystem"),
+            ("zip", create_zip_file, "fsspec.implementations.zip:ZipFileSystem"),
         ]
     )
     def test_pack_local_file_extract_filesystem(self, packing, create_packfile, filesystem_class, tmp_path):
@@ -211,8 +211,8 @@ class TestUnpackMessage:
     @pytest.mark.parametrize(
         ("packing", "create_packfile", "filesystem_class"),
         [
-            ("tar", create_tar_file, "fsspec.implementations.tar.TarFileSystem"),
-            ("zip", create_zip_file, "fsspec.implementations.zip.ZipFileSystem"),
+            ("tar", create_tar_file, "fsspec.implementations.tar:TarFileSystem"),
+            ("zip", create_zip_file, "fsspec.implementations.zip:ZipFileSystem"),
         ]
     )
     def test_pack_local_file_extract_with_custom_options(self, packing, create_packfile, filesystem_class, tmp_path):
@@ -296,6 +296,27 @@ class TestSingleFile:
                           "password": password,
                           "protocol": protocol,
                           "port": port}
+
         with pytest.raises(RuntimeError):
             _ = extract_local_files_to_message_for_remote_use(filename, topic,
                                                               target_options=target_options)
+
+
+def test_message_has_no_filesystem():
+    """Test that 'secret' and 'key' are stripped from the message."""
+    import datetime as dt
+    from dateutil import tz
+    from pytroll_collectors.fsspec_to_message import create_message_with_json_fs
+
+    jsn = ('{"cls": "s3fs.core.S3FileSystem", "protocol": "s3", "args": [], '
+           '"client_kwargs": {"endpoint_url": "https://lake.fmi.fi", '
+           '"aws_access_key_id": "xxx", "aws_secret_access_key": "yyy"}, '
+           '"secret": "xxx", "key": "yyy", "anon": false}')
+    file_ = {'key': 'bucket/test.bin', 'LastModified': dt.datetime.now(tz.UTC),
+             'name': 'bucket/test.bin', 'metadata': {}}
+    msg = create_message_with_json_fs(jsn, file_, '/subject')
+
+    assert 'secret' not in msg.data['filesystem']
+    assert 'key' not in msg.data['filesystem']
+    assert 'aws_access_key_id' not in msg.data['filesystem']['client_kwargs']
+    assert 'aws_secret_access_key' not in msg.data['filesystem']['client_kwargs']
